from flask import Flask
from flask_driver8 import driver8_blueprint

app = Flask(__name__)
app.register_blueprint(driver8_blueprint.driver8_blueprint)


def main():
    app.run(debug=True)


if __name__ == "__main__":
    main()



import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="Flask-Driver8",
    version="0.0.3",
    description="WebDriver server support for Flask applications",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://dev.azure.com/pumpitup/pumpo-number-five/",
    author="Gerogij Boljuba",
    author_email="georgij.boljuba@pumpitup.cz",
    license="Apache 2.0",
    classifiers=[
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Intended Audience :: Information Technology",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
    ],
    packages=["flask_driver8"],
    include_package_data=True,
    platforms='any',
    install_requires=[
        'Flask',
    ],
    entry_points={
        "console_scripts": [
            "driver8=flask_driver8.__main__:main",
        ]
    },
)



from flask import Blueprint, request
from flask import abort, jsonify, make_response
from uuid import uuid1
import re

driver8_blueprint = Blueprint('driver8_blueprint', __name__)

sessions = {}


def success(value, session_id):
    """Return successful response in the scope of particular Driver8 session"""
    return {'status': 0, 'value': value, 'sessionId': session_id}


def error(message, session_id):
    """Return error response in the scope of particular Driver8 session. Status 13 is interpreted as unknown error"""
    return {'status': 13, 'message': message, 'sessionId': session_id}


@driver8_blueprint.before_app_request
def check_session():
    match = re.match("/session/(.+?)/", request.path)
    if match and match.group(1) is not None:
        if match.group(1) not in sessions:
            abort(make_response(jsonify(message='Session not found'), 404))


@driver8_blueprint.route('/')
def index():
    return 'You are using Driver 8 (python) 0.0.3'


@driver8_blueprint.route('/status')
def status():
    return {'message': 'Driver8 (python) app version 0.0.3', 'ready': True}


@driver8_blueprint.route('/session', methods=['POST'])
def post():
    session_id = str(uuid1())
    sessions[session_id] = {}
    return success({}, session_id)


@driver8_blueprint.route('/session/<session_id>', methods=['GET'])
def get_session(session_id):
    if session_id in sessions:
        return success({}, session_id)
    else:
        abort(make_response(jsonify(message='Session not found'), 404))


@driver8_blueprint.route('/session/<session_id>', methods=['DELETE'])
def delete_session(session_id):
    if session_id in sessions:
        del sessions[session_id]
        return '', 204
    else:
        abort(make_response(jsonify(message='Session not found'), 404))
